if(getRversion() >= "2.10") {
  utils::globalVariables(c("FamilyM", "LinkM", "M", "M.fun", "S",  "conditional",
                           "covariates", "isCBPS.r", "isGlm.m", "isGlm.y", "isLm.m",
                           "isMultiConfounders", "isNominal.m", "isOrdinal.m",
                           "isSumStat.r", "n.y", "num.ms", "outcome", "pfun", "phi1",
                           "group", "w", "y.data",
                           "model.weights", "par", "contour", "points", "text",
                           "relevel", "vcov", "X", "cov", "var", "qnorm",
                           "weights"))
}